//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/ParticleItem.h
//! @brief     Defines class ParticleItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_PARTICLEITEM_H
#define BORNAGAIN_GUI_MODEL_SAMPLE_PARTICLEITEM_H

#include "GUI/Model/Descriptor/SelectionProperty.h"
#include "GUI/Model/Sample/FormFactorItems.h"
#include "GUI/Model/Sample/ItemWithMaterial.h"
#include "GUI/Model/Sample/ItemWithParticles.h"
#include <memory>

class Particle;

class ParticleItem : public ItemWithMaterial, public ItemWithParticles {
public:
    ParticleItem(const MaterialItems* materials);
    void serialize(Streamer& s) override;

    std::unique_ptr<Particle> createParticle() const;

    template <typename T>
    T* setFormFactorType();
    void setFormFactor(FormFactorItem* p);
    FormFactorItem* formfactor() const;
    QVector<ItemWithParticles*> containedItemsWithParticles() const override;

private:
    SelectionProperty<FormFactorItem*> m_formFactor;
};

template <typename T>
T* ParticleItem::setFormFactorType()
{
    T* p = new T();
    setFormFactor(p);
    return p;
}

#endif // BORNAGAIN_GUI_MODEL_SAMPLE_PARTICLEITEM_H
