//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Support/IO/IOUtils.cpp
//! @brief     Implements DatafieldUtils namespace
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Support/IO/IOUtils.h"
#include "Base/Axis/IAxis.h"
#include "Base/Util/Assert.h"
#include "Device/Data/Datafield.h"

// TODO: just clones the input, can probably be eliminated

std::unique_ptr<Datafield> GUI::Util::IO::binifyAxes(const Datafield& data)
{
    std::vector<IAxis*> axes;
    for (size_t i = 0; i < data.rank(); ++i)
        axes.emplace_back(data.axis(i).clone());

    auto result = std::make_unique<Datafield>(axes);

    result->setVector(data.flatVector());

    return result;
}
