//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/InstrumentEditController.cpp
//! @brief     Implements class InstrumentEditController
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Instrument/InstrumentEditController.h"
#include "GUI/Model/Descriptor/DoubleDescriptor.h"
#include "GUI/Model/Device/InstrumentItems.h"
#include "GUI/Model/Device/InstrumentsEditController.h"
#include "GUI/Model/Device/PointwiseAxisItem.h"

InstrumentEditController::InstrumentEditController(InstrumentsEditController* ec,
                                                   InstrumentItem* instrument)
    : m_instrumentItem(instrument)
    , m_ec(ec)
{
}

void InstrumentEditController::setInstrumentName(const QString& name)
{
    m_ec->setInstrumentName(m_instrumentItem, name);
}

void InstrumentEditController::setDouble(DoubleDescriptor& d, double newValue)
{
    if (d.get() != newValue) {
        d.set(newValue);
        m_ec->instrumentChanged(m_instrumentItem);
    }
}

void InstrumentEditController::notifyInstrumentChanged()
{
    m_ec->instrumentChanged(m_instrumentItem);
}

void InstrumentEditController::notifyWavelengthDistributionChanged()
{
    // update values in pointwise axis. This is necessary after a change of the mean value of the
    // wavelength.
    if (auto* specularBeam = dynamic_cast<SpecularBeamItem*>(m_instrumentItem->beamItem())) {
        if (auto* pw = dynamic_cast<PointwiseAxisItem*>(specularBeam->inclinationAxis()))
            pw->updateIndicators();
    }

    m_ec->instrumentChanged(m_instrumentItem);
}

void InstrumentEditController::notifyInclinationAxisChanged()
{
    // update wavelength. This is necessary after a change in the inclination axis type
    if (auto* specularBeam = dynamic_cast<SpecularBeamItem*>(m_instrumentItem->beamItem()))
        specularBeam->updateWavelength();
    m_ec->instrumentChanged(m_instrumentItem);
}
