//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Realspace/RealSpaceMesocrystalUtils.h
//! @brief     Defines GUI::RealSpace::BuilderUtils namespace
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_REALSPACE_REALSPACEMESOCRYSTALUTILS_H
#define BORNAGAIN_GUI_VIEW_REALSPACE_REALSPACEMESOCRYSTALUTILS_H

#include "GUI/View/Realspace/RealSpaceBuilderUtils.h"
#include "Sample/Scattering/Rotations.h"
#include <QVector3D>
#include <functional>

class Particle;
class Mesocrystal;
class MesocrystalItem;
class Particle3DContainer;

class RealSpaceMesocrystal {
public:
    ~RealSpaceMesocrystal() = default;

    RealSpaceMesocrystal(const MesocrystalItem* mesocrystalItem, double total_abundance,
                         const QVector3D& origin,
                         std::function<QColor(const QString&)> fnColorFromMaterialName);

    Particle3DContainer populateMesocrystal();

private:
    const MesocrystalItem* m_mesocrystalItem;
    double m_total_abundance;
    QVector3D m_origin;
    std::unique_ptr<GUI::RealSpace::BuilderUtils> m_builderUtils;
};

#endif // BORNAGAIN_GUI_VIEW_REALSPACE_REALSPACEMESOCRYSTALUTILS_H
